@@ -13,7 +13,7 @@ from aind_codeocean_api.codeocean import CodeOceanClient
 class MockResponse:
     """Mocks a rest request response"""
 
-    def __init__(self, content: dict, status_code: int) -> None:
+    def __init__(self, content: dict, status_code: int, url: str) -> None:
         """
         Creates a Mocked Response
         Parameters
@@ -23,6 +23,7 @@ class MockResponse:
         """
         self.content = content
         self.status_code = status_code
+        self.url = url
 
 
 class TestCodeOceanDataAssetRequests(unittest.TestCase):
@@ -56,17 +57,23 @@ class TestCodeOceanDataAssetRequests(unittest.TestCase):
         def request_post_response(json: dict) -> MockResponse:
             """Mock a post response"""
             success_message = map_input_to_success_message(json)
-            return MockResponse(status_code=200, content=success_message)
+            return MockResponse(
+                status_code=200, content=success_message, url=""
+            )
 
         def request_get_response(url: str) -> MockResponse:
             """Mock a get response"""
             success_message = map_input_to_success_message(url)
-            return MockResponse(status_code=200, content=success_message)
+            return MockResponse(
+                status_code=200, content=success_message, url=url
+            )
 
         def request_put_response(url: str, json: dict) -> MockResponse:
             """Mock a put response"""
             success_message = map_input_to_success_message(url, json)
-            return MockResponse(status_code=200, content=success_message)
+            return MockResponse(
+                status_code=200, content=success_message, url=url
+            )
 
         # TODO: Change these to enums
         if req_type == "post":
@@ -756,7 +763,7 @@ class TestCodeOceanDataAssetRequests(unittest.TestCase):
 
             def request_post_response(json: dict) -> MockResponse:
                 """Mock a post response"""
-                return MockResponse(status_code=204, content=None)
+                return MockResponse(status_code=204, content=None, url="")
 
             return request_post_response
 
@@ -794,7 +801,7 @@ class TestCodeOceanDataAssetRequests(unittest.TestCase):
 
             def request_post_response(json: dict) -> MockResponse:
                 """Mock a post response"""
-                return MockResponse(status_code=204, content=None)
+                return MockResponse(status_code=204, content=None, url="")
 
             return request_post_response
 
